<?php
// $Id: wordbook.inc,v 1.1.2.2 2008/02/12 04:32:34 mariuss Exp $

/*
  Xoops tables: xoops_wbcategories xoops_wbentries
*/

function xoops_import_module_wordbook_info() {
  $info = array(
    '#name' => t('WordBook'),
    '#help' => t('Import Xoops WordBook as into Drupal Glossary module'),
  );
  
  return $info;
}

function xoops_import_module_wordbook_configure() {
  $form = array();

  $form['wordbook']['xoops_import_module_wordbook_dirname'] = array(
    '#type' => 'textfield',
    '#title' => t('dirname'),
    '#return_value' => 1,
    '#default_value' => variable_get('xoops_import_module_wordbook_dirname', 'wordbook'),
    '#description' => t('The folder name of the wordbook module.'),
  );
  
  $form['wordbook']['xoops_import_module_wordbook_nodetype'] = array(
    '#type' => 'select',
    '#title' => t('Content Type'),
    '#options' => node_get_types('names'),
    '#default_value' => variable_get('xoops_import_module_wordbook_nodetype', 'page'),
    '#description' => t('The content type to use for glossary term details.'),
  );
  
  return $form;
}

function xoops_import_module_wordbook_confirm() {
  $disable = FALSE;
  $catCnt = 0;
  $wordCnt = 0;
  
  _xoops_import_db_connect();
  
  $xoops_import_table_preffix = variable_get('xoops_import_table_preffix', 'xoops');
  $x_wordbook_module_dir = variable_get('xoops_import_module_wordbook_dirname', 'wordbook');

  db_set_active('xoops');
  
  $wordbookRes = db_query("select COUNT(*) from {$xoops_import_table_preffix}_wbcategories");
  
  if ($wordbookRes) {
    $catCnt = db_result($wordbookRes);
  } else {
    $disable = TRUE;
  }
  
  $wordbookRes = db_query("select COUNT(*) from {$xoops_import_table_preffix}_wbentries where offline=0 and request=0");
  
  if ($wordbookRes) {
    $wordCnt = db_result($wordbookRes);
  } else {
    $disable = TRUE;
  }
  
  db_set_active('default');
  
  $form = array();
  
  if (_xoops_import_module_was_imported($x_wordbook_module_dir)) {
    $disable = TRUE;
    
    $form['wordbook'] = array(
      '#value' => '<p>' . t("WordBook already imported!") . '</p>',
    );
  }
  
  if (variable_get('xoops_import_module_wordbook_nodetype', '') == '') {
    $disable = TRUE;
    
    $form['nodetype'] = array(
      '#value' => '<p>' . t("Select a content type for glossary term details!") . '</p>',
    );
  }
  
  $form['cat_cnt'] = array(
    '#value' => '<p>' . t("WordBook categories: %cats", array('%cats' => $catCnt)) . '</p>',
  );
  
  $form['word_cnt'] = array(
    '#value' => '<p>' . t("WordBook entries: %words", array('%words' => $wordCnt)) . '</p>',
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Import'),
    '#disabled' => $disable,
  );

  return $form;
}

function xoops_import_module_wordbook_import() {
  _xoops_import_db_connect();
  
  $xoops_import_table_preffix = variable_get('xoops_import_table_preffix', 'xoops');
  
  $x_wordbook_module_dir = variable_get('xoops_import_module_wordbook_dirname', 'wordbook');
  $x_wordbook_module_id  = _xoops_import_get_xoops_module_id($x_wordbook_module_dir);
  
  $output = '';
  
  db_set_active('xoops');

  $wordbookCats = db_query("select * from {$xoops_import_table_preffix}_wbcategories order by categoryID");
  
  db_set_active('default');
  
  $cat_map = array();
  
  while ($row = db_fetch_array($wordbookCats)) {
    $output .= 'Creating category: ' . $row['name'] . '<br />';
    
    $edit = array();
    
    $edit['name'] = $row['name'];
    $edit['description'] = $row['description'];
    $edit['help'] = 'Select a glossary category';
    $edit['multiple'] = 0;
    $edit['required'] = 0;
    $edit['hierarchy'] = 0;
    $edit['relations'] = 0;
    $edit['tags'] = 0;
    $edit['weight'] = intval($row['weight']);
    $edit['module'] = 'taxonomy';
    $edit['nodes'] = array(variable_get('xoops_import_module_wordbook_nodetype', '') => TRUE);
    
    taxonomy_save_vocabulary($edit);
    
    $cat_map[$row['categoryID']] = $edit['vid'];
    
    _xoops_import_insert_redirect($row['categoryID'], $edit['vid'], $xoops_module_dir, 'category');
  }
  
  db_set_active('xoops');

  $wordbookEntries = db_query("select * from {$xoops_import_table_preffix}_wbentries where offline=0 and request=0 order by entryID");
  
  db_set_active('default');
  
  while ($row = db_fetch_array($wordbookEntries)) {
    $output .= 'Creating entry: ' . $row['term'] . '<br />';
    
    $edit = array();
    
    $edit['name'] = $row['term'];
    $edit['description'] = _xoops_import_module_wordbook_format(
      $row['definition'],
      $row['ref'],
      $row['url'],
      intval($row['html']),
      intval($row['smiley']),
      intval($row['xcodes']),
      intval($row['breaks'])
    );
    $edit['vid'] = $cat_map[$row['categoryID']];
    
    taxonomy_save_term($edit);
    
    _xoops_import_insert_redirect($row['entryID'], $edit['tid'], $xoops_module_dir, 'word');
  }
  
  _xoops_import_module_set_imported($x_wordbook_module_dir);

  print theme('page', $output);
  
  return;
}

function _xoops_import_module_wordbook_format($definition, $ref, $url, $html, $smiley, $xcodes, $breaks) {
  $text = $definition;
  
  if (!empty($ref)) {
    $text .= "\n\n$ref";
  }
  
  if (!empty($url)) {
    $text .= "\n\n$url";
  }
  
  return $text;
}

?>